@@ -4,7 +4,7 @@ sentry.conf.defaults
 
 Represents the default values for all Sentry settings.
 
-:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -93,12 +93,6 @@ MINUTE_NORMALIZATION = 15
 # The number of events to display per page
 MESSAGES_PER_PAGE = 15
 
-# Directory to stash log files in
-LOG_DIR = os.path.join(ROOT, 'log')
-
-# Directory to stash pid files in
-RUN_DIR = os.path.join(ROOT, 'run')
-
 # Web Service
 WEB_HOST = 'localhost'
 WEB_PORT = 9000
